<?php

namespace Teknisa\CTB\Services;

use Teknisa\CTB\Factories\Ctb24000BalanceteFactory;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Model\Contabilidade\Entities\Contopectbl;
use Teknisa\Model\Contabilidade\Entities\Lancccusto;
use Teknisa\Model\Contabilidade\Entities\Lanclote;
use Teknisa\Model\Contabilidade\Entities\Lanccont;
use Teknisa\Model\Geral\Entities\Centcustfil;
use Teknisa\Model\Geral\Entities\Contctbl;
use Teknisa\Model\Geral\Entities\Filial;

class Ctb24000BalanceteService {

    protected $entityManager;
    protected $environment;
    protected $lancamentosFactory;
    protected $newCode;
    
    const CD5_LENGTH = 5;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager, Environment $environment, Ctb24000BalanceteFactory $balanceteFactory, NewCode $newCode) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->balanceteFactory = $balanceteFactory;
        $this->newCode = $newCode;
    }

    /*
     * Função para verificar se uma data está entre outras duas.
     * Necessária para validar se a data do lançamento está dentro do período
     * contábil parametrizado.
     */
    private function betweenDates($compareDate, $beginDate, $endDate) {
        // É necessário truncar a data, removendo a hora, para que isso não
        // influencie na comparação.
        $beginDate = DateUtil::truncateData($beginDate);
        $endDate = DateUtil::truncateData($endDate);
        // Depois de truncada, a data final deve ser incrementada em um dia,
        // para que o último dia parametrizado também possa ser considerado.
        $endDate = DateUtil::adicionaIntervalo($endDate, 1, DateUtil::DIA);

        // Retorna true se a data não for menor que a primeira ou maior que a segunda.
        return !(DateUtil::comparaDatas($compareDate, $beginDate, DateUtil::ANTES) || DateUtil::comparaDatas($compareDate, $endDate, DateUtil::DEPOIS));
    }
    
    public function aplicarFiltroBalancete($row) {
        try{
            //var_dump($cdempresa);die();
            if($row['IDCONSOLIDADO'] == 'N'){
                $cdempresa = $row['CDEMPRESA'];
            }else{
                $cdempresa = implode('_', $row['CDEMPRESA']);
            }
            
            $cdcontini      = $row['CDCONTCTBLINI'];
            $cdcontfin      = $row['CDCONTCTBLFIN'];
            $datainic       = $row['DTINCLUSAO']["start"];
            $datafin        = $row['DTINCLUSAO']["end"];
            $nivel          = $row['CDNVCONT'];
            $encerramento   = $row['IDENCERRAMENTO'];
            
           $balancete = $this->balanceteFactory->execProcBALANCETE_OFICIAL(
               $cdempresa,
               $cdcontini,
               $cdcontfin,
               $datainic,
               $datafin,
               $nivel,
               $encerramento
            );
            //var_dump($balancete);die();
        } catch (\Exception $e) {
            throw $e;
        }
        return $balancete;
    }
    
    
}